agentle.mcp.prompts.prompt
==========================

.. automodule:: agentle.mcp.prompts.prompt

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      Prompt
      PromptArgument
      Sequence
   